@@ -30,6 +30,15 @@ class Bailador::Configuration {
 
     ## Terminal output
     has Bool $.terminal-color is rw = False;
+    has Str  $.terminal-color-trace is rw;
+    has Str  $.terminal-color-debug is rw;
+    has Str  $.terminal-color-info is rw;
+    has Str  $.terminal-color-notice is rw    = 'blue';
+    has Str  $.terminal-color-warning is rw   = 'yellow';
+    has Str  $.terminal-color-error is rw     = 'red';
+    has Str  $.terminal-color-critical is rw  = 'red';
+    has Str  $.terminal-color-alert is rw     = 'red';
+    has Str  $.terminal-color-emergency is rw = 'red';
 
     ## SESSION RELATED STUFF
     has Str $.cookie-name is rw       = 'bailador';
